Module: Vendors
- Defined in:
- lib/vendors/simple_navigation/renderer/breadcrumbs_without_method_links.rb,
lib/vendors/simple_navigation/renderer/twitter_sidenav.rb
Overview
Renders an ItemContainer as a
element and its containing items as elements.
It only renders 'selected' elements.
By default, the renderer sets the item's key as dom_id for the rendered element unless the config option autogenerate_item_ids is set to false.
The id can also be explicitely specified by setting the id in the html-options of the 'item' method in the config/navigation.rb file.
The ItemContainer's dom_class and dom_id are applied to the surrounding element.
Defined Under Namespace
Modules: SimpleNavigation